SystemOrganization addCategory: #'Seaside-Environment'!

!WADispatcher class methodsFor: '*seaside-environment' stamp: 'jf 9/30/2009 01:02'!
resetAll
	self 
		greaseDeprecatedApi: 'WADispatcher class>>#resetAll'
		details: 'Use WAEnvironment>>#reloadApplications.'.
	WAEnvironment reloadApplications! !

WARequestHandler subclass: #WALegacyRedirectionHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WALegacyRedirectionHandler commentStamp: 'pmm 2/18/2011 23:06' prior: 0!
I provide compatibility with old Seaside URLs that have Seaside in the path (eg. '/seaside/examples/counter') by simply removing it.!

!WALegacyRedirectionHandler class methodsFor: 'accessing' stamp: 'jf 11/24/2009 22:17'!
description
	^ 'Legacy redirection'! !

!WALegacyRedirectionHandler methodsFor: 'handling' stamp: 'pmm 9/5/2009 16:43'!
handleFiltered: aRequestContext
	| url |
	url := aRequestContext request url copy.
	url path removeFirst.
	aRequestContext response
		movedPermanently;
		location: url.
	aRequestContext respond! !

WAObject subclass: #WAEnvironment
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

WAEnvironment class
	instanceVariableNames: 'configuredApplicationDefaults configuredExceptionHandlingDefaults'!

WAEnvironment class
	instanceVariableNames: 'configuredApplicationDefaults configuredExceptionHandlingDefaults'!

!WAEnvironment class methodsFor: 'class initialization' stamp: 'jf 3/16/2009 08:31'!
configureApplicationDefaults
	(configuredApplicationDefaults ifNil: [ false ]) ifFalse: [
		WAAdmin applicationDefaults
			at: #responseGenerator put: WAHtmlResponseGenerator.
		configuredApplicationDefaults := true ].
	! !

!WAEnvironment class methodsFor: 'class initialization' stamp: 'jf 3/16/2009 08:32'!
configureApplicationExceptionHandlingDefaults
	(configuredExceptionHandlingDefaults ifNil: [ false ]) ifFalse: [
		WAAdmin applicationExceptionHandlingDefaults
			at: #exceptionHandler put: WAHtmlErrorHandler.
		configuredExceptionHandlingDefaults := true ].
	! !

!WAEnvironment class methodsFor: 'class initialization' stamp: 'jf 3/15/2009 18:51'!
initialize
	self configureApplicationDefaults.
	self configureApplicationExceptionHandlingDefaults.
	self registerDefaultRequestHandlers.
	self registerDefaultComponents! !

!WAEnvironment class methodsFor: 'registration' stamp: 'jf 3/15/2009 18:47'!
registerDefaultComponents
	WAPainter allSubclasses do: [ :each |
		(each class includesSelector: #initialize)
			ifTrue: [ each initialize ] ]! !

!WAEnvironment class methodsFor: 'registration' stamp: 'jf 11/24/2009 22:18'!
registerDefaultRequestHandlers
	WAFileHandler default: WAFileHandler new.
	WAFileHandler default 
		preferenceAt: #fileHandlerListingClass
		put: WAHtmlFileHandlerListing.
	WAAdmin defaultDispatcher 
		register: WAFileHandler default
		at: 'files'.
	WAAdmin defaultDispatcher 
		register: WALegacyRedirectionHandler new
		at: 'seaside'! !

!WAEnvironment class methodsFor: 'registration' stamp: 'jf 3/15/2009 18:51'!
reloadApplications
	WAAdmin clearAll.
	self registerDefaultRequestHandlers.
	self registerDefaultComponents! !

WAFileHandlerListing subclass: #WAHtmlFileHandlerListing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'as 2/6/2011 22:05'!
responseForLibraries
	| title contents |
	title := 'Index of ', handler url pathString.
	contents := WAHtmlCanvas builder
		fullDocument: true;
		rootBlock: [ :html | html title: title ];
		render: [ :html |
			html heading: title.
			html unorderedList: [
				handler libraries do: [ :each |
					html listItem: [
						html anchor
							url: (each urlOf: '');
							with: each name ] ] ] ].
	context respond: [ :response |
		response
			contentType: WAMimeType textHtml;
			nextPutAll: contents ]! !

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'NickAger 3/8/2012 23:45'!
responseForLibrary: aLibrary
	| title contents |
	title := 'Index of ', aLibrary name.
	contents := WAHtmlCanvas builder
		fullDocument: true;
		rootBlock: [ :html | html title: title ];
		render: [ :html |
			html heading level: 1; with: title.
			html table: [
				html tableRow: [
					html tableHeading: 'Name'.
					html tableHeading: 'Size'.
					html tableHeading: 'Description' ].
				aLibrary fileSelectors do: [ :each |
					html tableRow: [
						html tableData: [
							html anchor
								url: (aLibrary urlOf: each);
								with: (aLibrary asFilename: each) ].
						html tableData: (aLibrary fileSizeOf: each).
						html tableData: (aLibrary mimetypeOf: each) ] ] ] ].
	context respond: [ :response |
		response
			contentType: WAMimeType textHtml;
			nextPutAll: contents ]! !

WAErrorHandler subclass: #WAHtmlErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlErrorHandler commentStamp: 'jf 11/10/2008 10:07' prior: 0!
This exception handler returns a simple HTML error message response for Warnings and Errors.

It provides two methods to allow the easy creation of custom error responses:

#titleForException:  - can be used to override the text displayed in the title
#renderContentForException:  - can be used to fully customize the HTML output!

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 8/31/2009 19:56'!
handleDefault: anException
	self requestContext respond: [ :response |
		response
			internalError;
			contentType: WAMimeType textHtml;
			nextPutAll: (self rendererClass builder
				fullDocument: true;
				rootBlock: [ :root | self updateHtmlRoot: root forException: anException ];
				render: [ :html | self renderContentForException: anException on: html ]) ]! !

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 11/10/2008 10:04'!
renderContentForException: anException on: html
	html heading level1; with: anException description.
	html paragraph: 'Your request could not be completed. An exception occurred.'! !

!WAHtmlErrorHandler methodsFor: 'accessing' stamp: 'as 2/6/2011 22:05'!
rendererClass
	^ WAHtmlCanvas! !

!WAHtmlErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 20:28'!
titleForException: anException
	^ anException description! !

!WAHtmlErrorHandler methodsFor: 'content' stamp: 'jf 8/31/2009 19:58'!
updateHtmlRoot: anHtmlRoot forException: anException
	anHtmlRoot title: (self titleForException: anException)! !

WAResponseGenerator subclass: #WAHtmlResponseGenerator
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlResponseGenerator commentStamp: 'lr 2/20/2009 11:16' prior: 0!
This subclass overrides certain generation methods to create prettier HTML responses, instead of plain text.!

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'as 2/6/2011 22:05'!
forbidden
	self response
		forbidden;
		contentType: WAMimeType textHtml;
		nextPutAll: (WAHtmlCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Forbidden' ];
			render: [ :html |
				html heading: [
					html text: 'Error: you are forbidden to access "'.
					html text: self request url pathString.
					html text: '"' ] ])! !

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'as 2/6/2011 22:05'!
notFound
	self response
		notFound;
		contentType: WAMimeType textHtml;
		nextPutAll: (WAHtmlCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Not Found' ];
			render: [ :html |
				html heading: [
					html text: 'Error: "'.
					html text: self request url pathString.
					html text: '" not found' ] ])! !

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'as 2/6/2011 22:05'!
pageExpired
	self response
		doNotCache;
		contentType: WAMimeType textHtml;
		nextPutAll: (WAHtmlCanvas builder
			fullDocument: true;
			rootBlock: [ :root | root title: 'Page Expired' ];
			render: [ :html | 
				html heading: 'Page Expired'.
				html paragraph: 'This page has expired. Please use the back-button to navigate to the last valid page.' ])! !

!WAHtmlResponseGenerator methodsFor: 'generation' stamp: 'pmm 6/26/2011 14:11'!
refreshAfter: aNumber location: aUrlOrString message: aString 
	self response
		contentType: WAMimeType textHtml;
		refreshAfter: aNumber
			location: aUrlOrString;
		nextPutAll: (WAHtmlCanvas builder
				fullDocument: true;
				render: [ :html | 
					html heading: aString.
					html paragraph: [
						html text: 'You are being redirected to '.
						html anchor
							url: aUrlOrString;
							with: aUrlOrString greaseString ] ])! !

!GRPackage class methodsFor: '*seaside-environment' stamp: 'jf 6/24/2010 12:36'!
seasideEnvironment
	^ self new
		name: 'Seaside-Environment';
		description: 'The standard Seaside distribution environment. This package can depend on all other code packages as needed.';
		addDependency: 'Seaside-Tools-Core';
		addDependency: 'Seaside-Core';
		addDependency: 'Seaside-Component';
		addDependency: 'Seaside-RenderLoop';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Canvas';
		addDependency: 'Seaside-Widgets'; "Users expect #inform:, etc. to be available"
		url: #seasideUrl;
		yourself! !
WAEnvironment initialize!
